@@ -1,11 +1,10 @@
 import logging
 import os
 
-import requests
-
 from ravenpackapi import Dataset
 from ravenpackapi.exceptions import APIException
 from ravenpackapi.models.dataset_list import DatasetList
+from ravenpackapi.models.job import Job
 from ravenpackapi.models.mapping import RPMappingResults
 from ravenpackapi.models.reference import RpEntityReference, EntityTypeReference
 from ravenpackapi.models.results import Results
@@ -13,9 +12,10 @@ from ravenpackapi.upload.module import UploadApi
 from ravenpackapi.util import to_curl
 from ravenpackapi.utils.constants import ENTITY_TYPES
 from ravenpackapi.utils.date_formats import as_datetime_str
+from ravenpackapi.utils.dynamic_sessions import DynamicSession
 
 _VALID_METHODS = ('get', 'post', 'put', 'delete', 'patch')
-VERSION = '1.0.38'
+VERSION = '1.0.40'
 
 logger = logging.getLogger("ravenpack.core")
 
@@ -45,6 +45,7 @@ class RPApi(object):
             )
         self.api_key = api_key
         self.log_curl_commands = True
+        self.session = DynamicSession()
         self.upload = UploadApi(self)
 
     @property
@@ -62,7 +63,7 @@ class RPApi(object):
             'Method {used} not accepted. Please choose one of {valid_methods}'.format(
                 used=method, valid_methods=", ".join(_VALID_METHODS)
             )
-        requests_call = getattr(requests, method)
+        requests_call = getattr(self.session, method)
         logger.debug("Request {method} to {endpoint}".format(method=method,
                                                              endpoint=endpoint))
         if endpoint.startswith("http://") or endpoint.startswith("https://"):
@@ -105,6 +106,14 @@ class RPApi(object):
                 response.json()['datasets'])
         )
 
+    def list_jobs(self, start_date, end_date, status=None):
+        response = self.request('/jobs', params={
+            "start_date": as_datetime_str(start_date),
+            "end_date": as_datetime_str(end_date),
+            "status": status
+        })
+        return [Job(self, job) for job in response.json()['jobs']]
+
     def create_dataset(self, dataset):
         # be sure to create a copy
         new_dataset_data = dataset.as_dict()
