@@ -1,5 +1,7 @@
 from functools import wraps
 
+import requests
+
 
 class APIException(Exception):
     def __init__(self, *args, **kwargs):
@@ -18,6 +20,13 @@ class DataFileTimeout(Exception):
     pass
 
 
+class JobNotProcessing(Exception):
+    def __init__(self, *args, **kwargs):
+        status = kwargs.pop('status', None)
+        super(JobNotProcessing, self).__init__(*args)
+        self.status = status
+
+
 def api_method(func):
     @wraps(func)
     def decorated_func(instance, *args, **kwargs):
@@ -30,3 +39,7 @@ def api_method(func):
 
 class ValidationError(Exception):
     pass
+
+
+class ApiConnectionError(requests.ConnectionError):
+    pass
